@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.174 2006/12/14 20:49:23 albertel Exp $
+# $Id: lonroles.pm,v 1.177 2007/04/17 15:44:58 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -438,18 +438,18 @@ ENDHEADER
     }
 # -------------------------------------------------------- Choice or no choice?
     if ($nochoose) {
-	$r->print("<h2>".&mt('Sorry ...')."</h2>\n".
-		  &mt('This action is currently not authorized.').
+	$r->print("<h2>".&mt('Sorry ...')."</h2>\n<span class='LC_error'>".
+		  &mt('This action is currently not authorized.').'</span>'.
 		  &Apache::loncommon::end_page());
 	return OK;
     } else {
         if ($advanced) {
-	    $r->print(&mt("Your home server is ").
-		      $Apache::lonnet::hostname{&Apache::lonnet::homeserver
-                      ($env{'user.name'},$env{'user.domain'})}.
+	    $r->print('<span class="LC_rolesinfo">'.&mt("Your home server is ").
+		      &Apache::lonnet::hostname(&Apache::lonnet::homeserver
+                      ($env{'user.name'},$env{'user.domain'})).
 		      "<br />\n");
 	    $r->print(&mt(
-      "Author and Co-Author roles are not available on servers other than their respective home servers."));
+      "Author and Co-Author roles are not available on servers other than their respective home servers.").'</span>');
         }
         if (($ENV{'REDIRECT_QUERY_STRING'}) && ($fn)) {
     	    $fn.='?'.$ENV{'REDIRECT_QUERY_STRING'};
@@ -461,9 +461,9 @@ ENDHEADER
     }
     if ($env{'user.adv'}) {
 	$r->print(
-	      '<br /><label>'.&mt('Show all roles').': <input type="checkbox" name="showall"');
+	      '<br /><span class="LC_rolesinfo"><label>'.&mt('Show all roles').': <input type="checkbox" name="showall"');
 	if ($env{'form.showall'}) { $r->print(' checked="checked" '); }
-	$r->print(' /></label><input type="submit" value="'.&mt('Display').'" />');
+	$r->print(' /></label><input type="submit" value="'.&mt('Display').'" /></span>');
     }
 
     my (%roletext,%sortrole,%roleclass);
@@ -546,7 +546,7 @@ ENDHEADER
                         $switchserver='otherserver='.$home.'&role='.$trolecode;
                     }
                     #next if ($home eq 'no_host');
-                    $home = $Apache::lonnet::hostname{$home};
+                    $home = &Apache::lonnet::hostname($home);
                     $ttype='Construction Space';
                     $twhere=&mt('User').': '.$trest.'<br />'.&mt('Domain').
 			': '.$tdom.'<br />'.
@@ -566,7 +566,7 @@ ENDHEADER
                         $switchserver='otherserver='.$home.'&role='.$trolecode;
                     }
                     #next if ($home eq 'no_host');
-                    $home = $Apache::lonnet::hostname{$home};
+                    $home = &Apache::lonnet::hostname($home);
                     $ttype='Construction Space';
                     $twhere=&mt('Domain').': '.$tdom.'<br />'.&mt('Server').
 			':&nbsp;'.$home;
@@ -604,7 +604,7 @@ ENDHEADER
                         }
                     }
                     if ($tsection) {
-                        $twhere.='<br />'.&mt('Section/Group').': '.$tsection;
+                        $twhere.='<br />'.&mt('Section').': '.$tsection;
 		    }
 		    if ($role ne 'st') { $twhere.="<br />".&mt('Domain').":".$tdom; }
                 } elsif ($tdom) {
@@ -648,7 +648,7 @@ ENDHEADER
     unless (($advanced) || ($nochoose)) {
 	$r->print("<h2>".&mt('Select a Course to Enter')."</h2>\n");
     }
-    $r->print('<br /><table><tr>');
+    $r->print('<br /><table id="LC_rolesmenu"><tr>');
     unless ($nochoose) { $r->print('<th>&nbsp;</th>'); }
     $r->print('<th>'.&mt('User Role').'</th><th>'.&mt('Extent').
          '</th><th>'.&mt('Start').'</th><th>'.&mt('End').'</th></tr>'."\n");
@@ -730,8 +730,8 @@ ENDHEADER
 	    $r->print('<td>&nbsp;</td>');
 	}
     }
-    $r->print('<td colspan="3"><font color="'.$tfont.'">'.&mt('No role specified').
-      '</font></td><td><font color="'.$tfont.'">'.$tremark.
+    $r->print('<td colspan="3"><font color="'.$tfont.'"><span class="LC_rolesinfo">'.&mt('No role specified').
+      '</font></span></td><td><font color="'.$tfont.'">'.$tremark.
       '&nbsp;</font></td></tr>'."\n");
 
     $r->print('</table>');
@@ -741,57 +741,7 @@ ENDHEADER
 # ------------------------------------------------------------ Privileges Info
     if (($advanced) && (($env{'user.error.msg'}) || ($error))) {
 	$r->print('<hr /><h2>Current Privileges</h2>');
-
-	foreach $envkey (sort keys %env) {
-	    if ($envkey=~/^user\.priv\.$env{'request.role'}\./) {
-		my $where=$envkey;
-		$where=~s/^user\.priv\.$env{'request.role'}\.//;
-		my $ttype;
-		my $twhere;
-		my ($tdom,$trest,$tsec)=
-		    split(/\//,Apache::lonnet::declutter($where));
-		if ($trest) {
-		    if ($env{'course.'.$tdom.'_'.$trest.'.description'} eq 'ca') {
-			$ttype='Construction Space';
-			$twhere='User: '.$trest.', Domain: '.$tdom;
-		    } else {
-			$ttype= 
-			    &Apache::loncommon::course_type($tdom.'_'.$trest);
-			$twhere=$env{'course.'.$tdom.'_'.$trest.'.description'};
-			if ($tsec) {
-			    $twhere.=' (Section: '.$tsec.')';
-			}
-		    }
-		} elsif ($tdom) {
-		    $ttype='Domain';
-		    $twhere=$tdom;
-		} else {
-		    $ttype='System';
-		    $twhere='/';
-		}
-		$r->print("\n<h3>".$ttype.': '.$twhere.'</h3><ul>');
-		foreach (sort split(/:/,$env{$envkey})) {
-		    if ($_) {
-			my ($prv,$restr)=split(/\&/,$_);
-			my $trestr='';
-			if ($restr ne 'F') {
-			    my $i;
-			    $trestr.=' (';
-			    for ($i=0;$i<length($restr);$i++) {
-				$trestr.=
-			       Apache::lonnet::plaintext(substr($restr,$i,1));
-				if ($i<length($restr)-1) { $trestr.=', '; }
-			    }
-			    $trestr.=')';
-			}
-			$r->print('<li>'.
-				  Apache::lonnet::plaintext($prv).$trestr.
-				  '</li>');
-		    }
-		}
-		$r->print('</ul>');
-	    }
-	}
+	$r->print(&privileges_info());
     }
     $r->print(&Apache::lonnet::getannounce());
     if ($advanced) {
@@ -803,6 +753,61 @@ ENDHEADER
     return OK;
 }
 
+sub privileges_info {
+    my ($which) = @_;
+    my $output;
+
+    $which ||= $env{'request.role'};
+
+    foreach my $envkey (sort(keys(%env))) {
+	next if ($envkey!~/^user\.priv\.\Q$which\E\.(.*)/);
+
+	my $where=$1;
+	my $ttype;
+	my $twhere;
+	my (undef,$tdom,$trest,$tsec)=split(m{/},$where);
+	if ($trest) {
+	    if ($env{'course.'.$tdom.'_'.$trest.'.description'} eq 'ca') {
+		$ttype='Construction Space';
+		$twhere='User: '.$trest.', Domain: '.$tdom;
+	    } else {
+		$ttype= &Apache::loncommon::course_type($tdom.'_'.$trest);
+		$twhere=$env{'course.'.$tdom.'_'.$trest.'.description'};
+		if ($tsec) {
+		    my $sec_type = 'Section';
+		    if (exists($env{"user.role.gr.$where"})) {
+			$sec_type = 'Group';
+		    }
+		    $twhere.=' ('.$sec_type.': '.$tsec.')';
+		}
+	    }
+	} elsif ($tdom) {
+	    $ttype='Domain';
+	    $twhere=$tdom;
+	} else {
+	    $ttype='System';
+	    $twhere='/';
+	}
+	$output .= "\n<h3>".$ttype.': '.$twhere.'</h3>'."\n<ul>";
+	foreach my $priv (sort(split(/:/,$env{$envkey}))) {
+	    next if (!$priv);
+
+	    my ($prv,$restr)=split(/\&/,$priv);
+	    my $trestr='';
+	    if ($restr ne 'F') {
+		$trestr.=' ('.
+		    join(', ',
+			 map { &Apache::lonnet::plaintext($_) } 
+			     (split('',$restr))).') ';
+	    }
+	    $output .= "\n\t".
+		'<li>'.&Apache::lonnet::plaintext($prv).$trestr.'</li>';
+	}
+	$output .= "\n".'</ul>';
+    }
+    return $output;
+}
+
 sub role_status {
     my ($rolekey,$then,$now,$role,$where,$trolecode,$tstatus,$tstart,$tend) = @_;
     my @pwhere = ();
@@ -830,7 +835,7 @@ sub role_status {
 
 sub build_roletext {
     my ($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$tfont,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver) = @_;
-    my $roletext='<tr bgcolor="'.$tbg.'">';
+    my $roletext='<tr bgcolor="'.$tbg.'" class="LC_rolesmenu_'.$tstatus.'">';
     my $is_dc=($trolecode =~ m/^dc\./);
     my $rowspan=($is_dc) ? ''
                          : ' rowspan="2" ';
@@ -840,8 +845,8 @@ sub build_roletext {
         $buttonname=~s/\W//g;
         if (!$button) {
             if ($switchserver) {
-                $roletext.='<td'.$rowspan.'><a href="/adm/switchserver?'.
-                $switchserver.'">'.&mt('Switch Server').'</a></td>';
+                $roletext.='<td'.$rowspan.'><span class="LC_rolesinfo"><a href="/adm/switchserver?'.
+                $switchserver.'">'.&mt('Switch Server').'</a></span></td>';
             } else {
                 $roletext.=('<td'.$rowspan.'>&nbsp;</td>');
             }
@@ -873,8 +878,8 @@ sub build_roletext {
                '</font></td><td><font color="'.$tfont.'">'.$tpend.
                '</font></td></tr>';
     if (!$is_dc) {
-	$roletext.='<tr bgcolor="'.$tbg.'"><td colspan="4"><font color="'.$tfont.'">'.$tremark.
-	    '&nbsp;</font></td></tr><tr><td colspan="5" height="3"></td></tr>'."\n";
+	$roletext.='<tr bgcolor="'.$tbg.'"><td colspan="4"><font color="'.$tfont.'"><span class="LC_rolesinfo">'.$tremark.
+	    '</span>&nbsp;</font></td></tr><tr><td colspan="5" height="3"></td></tr>'."\n";
     }
     return $roletext;
 }
@@ -1027,10 +1032,9 @@ sub allcourses_row {
                  ' <td colspan="5">';
     my $selectlink = &courselink($dcdom,$rowtype);
     my $ccrole = &Apache::lonnet::plaintext('cc');
-    $output.= '<font color="#002200">'.$ccrole.'</font>'.
-              ' <b>'.$selectlink.'</b>'.
-              ' from '.&mt('Domain').' '.$dcdom.'<br />';
-    $output .= '</tr><tr><td colspan="5" height="3"></td></tr>'."\n";
+    $output.= '<span class="LC_rolesinfo">'.
+            &mt('[_1]: [_2] from domain [_3]',$ccrole,$selectlink,$dcdom).
+            '</span><br /></tr><tr><td colspan="5" height="3"></td></tr>'."\n";
     return $output;
 }
 
