@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Switch Servers Handler
 #
-# $Id: switchserver.pm,v 1.11 2007/01/12 15:44:27 raeburn Exp $
+# $Id: switchserver.pm,v 1.13 2007/03/02 23:17:48 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -68,10 +68,10 @@ sub handler {
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
 					    ['otherserver','role']);
 
-    my $switch_to=$Apache::lonnet::hostname{$env{'form.otherserver'}};
+    my $switch_to=&Apache::lonnet::hostname($env{'form.otherserver'});
     if (!$env{'form.otherserver'}) {
 	$env{'form.otherserver'}=&Apache::lonnet::spareserver(30000,undef,1);
-	$switch_to=$Apache::lonnet::hostname{$env{'form.otherserver'}};
+	$switch_to=&Apache::lonnet::hostname($env{'form.otherserver'});
     }
 
     if (!defined($switch_to)) { return FORBIDDEN; }
@@ -89,6 +89,12 @@ sub handler {
 			 "Switch Server to $env{'form.otherserver'} with role $env{'form.role'} $ENV{'REMOTE_ADDR'}");
 
     &Apache::loncommon::content_type($r,'text/html');
+
+    #expire the cookie
+    my $c = new CGI::Cookie(-name    => 'lonID',
+			    -value   => '',
+			    -expires => '-10y',);
+    $r->header_out('Set-cookie' => $c);
     $r->send_http_header;
     return OK if $r->header_only;
 # -------------------------------------------------------- Menu script and info
