@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # caparesponse definition
 #
-# $Id: caparesponse.pm,v 1.214 2007/05/22 00:45:43 albertel Exp $
+# $Id: caparesponse.pm,v 1.216 2007/06/06 17:03:54 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -392,9 +392,6 @@ sub setup_capa_args {
 sub setup_capa_response {
     my ($args_ref,$response) = @_;   
 
-    use Data::Dumper;
-    &Apache::lonxml::debug("response dump is ".&Dumper($response));
-    
     if (ref($response)) {
 	$$args_ref{'response'}=dclone($response);
     } else {
@@ -824,8 +821,6 @@ sub check_for_answer_errors {
 	} (sort(keys(%counts))));
 	&Apache::lonxml::error(&mt("All answers must have the same number of components. Varying numbers of answers were seen. ").$counts);
     }
-    use Data::Dumper;
-    &Apache::lonxml::debug("count dump is ".&Dumper(\%counts));
     my $expected_number_of_inputs = (keys(%counts))[0];
     if ( $expected_number_of_inputs > 0 
 	 && $expected_number_of_inputs != scalar(@Apache::inputtags::inputlist)) {
@@ -864,7 +859,13 @@ sub get_table_sizes {
     my $bubbles_per_line=int($textwidth/$cell_width);
     if ($bubbles_per_line > $number_of_bubbles) {
 	$bubbles_per_line=$number_of_bubbles;
-    }elsif (($bubbles_per_line > $number_of_bubbles/2) && ($number_of_bubbles % 2==0)) {$bubbles_per_line=$number_of_bubbles/2;}
+    } elsif (($bubbles_per_line > $number_of_bubbles/2) 
+	     && ($number_of_bubbles % 2==0)) {
+	$bubbles_per_line=$number_of_bubbles/2;
+    }
+    if ($bubbles_per_line < 1) {
+	$bubbles_per_line=1;
+    }
     my $number_of_tables = int($number_of_bubbles/$bubbles_per_line);
     my @table_range = ();
     for (my $i=0;$i<$number_of_tables;$i++) {push @table_range,$bubbles_per_line;}
@@ -899,6 +900,11 @@ sub format_number {
 
 sub make_numerical_bubbles {
     my ($part,$id,$target,$parstack,$safeeval) =@_;
+
+    if (!%answer) {
+	&Apache::lonxml::error(&mt("No answers defined for response [_1] in part [_2] to make bubbles for.",$id,$part));
+	return ([],[],undef);
+    }
     
     my $number_of_bubbles = 
 	&Apache::response::get_response_param($part.'_'.$id,'numbubbles',8);
