@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # essay (ungraded) style responses
 #
-# $Id: essayresponse.pm,v 1.81 2007/01/08 11:12:44 foxr Exp $
+# $Id: essayresponse.pm,v 1.82 2007/04/17 23:25:09 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -175,6 +175,11 @@ sub end_essayresponse {
 						{'no_verbatim' => 1});
 	$result.=&Apache::response::answer_footer($$tagstack[-1]);
     }
+    if ($target eq 'web') {
+	&Apache::response::setup_prior_tries_hash(\&format_prior_response,
+						  ['portfiles',
+						   'uploadedurl']);
+    }
 
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' ||
 	$target eq 'tex' || $target eq 'analyze') {
@@ -185,6 +190,36 @@ sub end_essayresponse {
     return $result;
 }
 
+sub format_prior_response {
+    my ($mode,$answer,$other_data) = @_;
+    my $output;
+
+    my (undef,undef,$udom,$uname) = &Apache::lonnet::whichuser();
+    my $port_url = '/uploaded/'.$udom.'/'.$uname.'/portfolio/';
+
+    my $file_list;
+
+    foreach my $file (split(/\s*,\s*/,
+			    $other_data->[0].','.$other_data->[1])) {
+	next if ($file!~/\S/);
+	if ($file !~ m{^/uploaded/}) { $file=$port_url.$file; }
+	$file=~s|/+|/|g;
+	&Apache::lonnet::allowuploaded('/adm/essayresponse',$file);
+	$file_list.='<li><span class="LC_nobreak"><a href="'.$file.'?rawmode=1" target="lonGRDs"><img src="'.
+	    &Apache::loncommon::icon($file).'" alt="file icon" border="0" /> '.$file.
+	    '</a></span></li>'."\n";
+    }
+    if ($file_list) {
+	$output.= &mt('Submitted Files').'<ul>'.$file_list.'</ul>';
+    }
+    if ($answer =~ /\S/) {
+	$output.='<p>'.&mt('Submitted text').
+	    '<blockquote>'.$answer.'</blockquote></p>';
+    }
+
+    return '<div class="LC_prior_essay">'.$output.'</div>';
+}
+
 sub file_submission {
     my ($part,$id,$which,$award,$uploadedflag)=@_;
     my $files;
