@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.225 2007/05/21 23:09:57 albertel Exp $
+# $Id: inputtags.pm,v 1.226 2007/05/29 21:14:45 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1180,7 +1180,7 @@ sub previous_tries {
 	    my ($match,$which) = &find_which_previous($i);
 	    $message=$previousmsg;
 	    my $previous = $count_lookup{$which};
-	    $message =~ s{(</td>)}{ as submission # $previous $1};
+	    $message =~ s{(</td>)}{ as submission \# $previous $1};
 	} elsif ($Apache::lonhomework::history{"$prefix.tries"}) {
 	    if (!(lc($Apache::lonhomework::problemstatus) eq 'no'
 		  && $Apache::inputtags::status[-1] ne 'SHOW_ANSWER')
@@ -1228,6 +1228,8 @@ sub previous_tries {
     $output=~s/\\/\\\\/g;
     $output=~s/\'/\\\'/g;
     $output=~s/\s+/ /g;
+    $output.='<br /><form action=""><center><input type="button" name="close" value="'.&mt('Close Window').'" onClick="window.close()" /></center></form>';
+
     my $windowopen=&Apache::lonhtmlcommon::javascript_docopen();
     my $start_page =
 	&Apache::loncommon::start_page('Previous Tries', undef,
