@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Interface routines to MAXIMA CAS
 #
-# $Id: lonmaxima.pm,v 1.13 2007/04/19 17:40:43 raeburn Exp $
+# $Id: lonmaxima.pm,v 1.15 2007/05/29 20:56:39 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -60,7 +60,9 @@ sub maximareply {
 
 sub blacklisted {
     my ($cmd)=@_;
-    foreach my $forbidden ('save','load','plot','lisp','includ','compil','file','batch','stringout','translat','stout','stin','block','system') {
+    foreach my $forbidden ('save','load','plot','lisp','includ','compil',
+			   'file','batch','stringout','translat','stout',
+			   'stin','block','system','concat') {
 	if ($cmd=~/$forbidden/s) { return 1; }
     } 
     return 0;
@@ -75,7 +77,9 @@ sub runscript {
 	if ($line=~/\w/) { $reply=&maximareply($socket,$line.";\n"); }
 	if ($reply=~/^Error\:/) { return $reply; }
     }
-    $reply=~s/\W//gs;
+    $reply=~s/^\s*//gs;
+    $reply=~s/\s*$//gs;
+    &Apache::lonxml::debug("maxima $fullscript \n reply $reply");
     return $reply;
 }
 
