@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.152 2006/12/04 21:23:01 albertel Exp $
+# $Id: response.pm,v 1.167 2007/05/23 22:36:21 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -30,6 +30,7 @@ package Apache::response;
 use strict;
 use Apache::lonlocal;
 use Apache::lonnet;
+use Apache::lonmaxima();
 
 BEGIN {
     &Apache::lonxml::register('Apache::response',('responseparam','parameter','dataresponse','customresponse','mathresponse'));
@@ -264,11 +265,14 @@ sub meta_response_order {
 }
 
 sub check_for_previous {
-    my ($curresponse,$partid,$id) = @_;
+    my ($curresponse,$partid,$id,$last) = @_;
     my %previous;
     $previous{'used'} = 0;
     foreach my $key (sort(keys(%Apache::lonhomework::history))) {
 	if ($key =~ /resource\.$partid\.$id\.submission$/) {
+	    if ( $last && $key =~ /^(\d+):/ ) {
+		next if ($1 >= $last);
+	    }
 	    &Apache::lonxml::debug("Trying $key");
 	    my $pastresponse=$Apache::lonhomework::history{$key};
 	    if ($pastresponse eq $curresponse) {
@@ -367,7 +371,8 @@ sub start_customresponse {
     my $id = &Apache::response::start_response($parstack,$safeeval);
     push(@Apache::lonxml::namespace,'customresponse');
     my $result;
-    undef($Apache::response::custom_answer);
+    @Apache::response::custom_answer=();
+    @Apache::response::custom_answer_type=();
     &Apache::lonxml::register('Apache::response',('answer'));
     if ($target eq 'web') {
   	if (  &Apache::response::show_answer() ) {
@@ -386,7 +391,6 @@ sub start_customresponse {
 						  $safeeval,'answerdisplay');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     } elsif ($target eq 'answer' || $target eq 'grade') {
 	&Apache::response::reset_params();
@@ -407,7 +411,7 @@ sub end_customresponse {
 	    &Apache::response::submitted('scantron')) {
 	    &Apache::response::scored_response($part,$id);
 	} elsif ( $response =~ /[^\s]/ && 
-		  $Apache::response::custom_answer_type eq 'loncapa/perl') {
+		  $Apache::response::custom_answer_type[-1] eq 'loncapa/perl') {
 	    if (!$Apache::lonxml::default_homework_loaded) {
 		&Apache::lonxml::default_homework_load($safeeval);
 	    }
@@ -419,7 +423,7 @@ sub end_customresponse {
 	    ${$safeeval->varglob('LONCAPA::customresponse_submission')}=
 		$response;
 	    
-	    my $award = &Apache::run::run('{ my $submission=$LONCAPA::customresponse_submission;'.$Apache::response::custom_answer.'}',$safeeval);
+	    my $award = &Apache::run::run('{ my $submission=$LONCAPA::customresponse_submission;'.$Apache::response::custom_answer[-1].'}',$safeeval);
 	    if (!&Apache::inputtags::valid_award($award)) {
 		$error = $award;
 		$award = 'ERROR';
@@ -442,23 +446,34 @@ sub end_customresponse {
 	$result .= &Apache::response::answer_part('customresponse',$answer);
 	$result .= &Apache::response::answer_footer('customresponse');
     }
+    if ($target eq 'web') {
+	&setup_prior_tries_hash(\&format_prior_response_math);
+    }
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
 	&Apache::lonxml::increment_counter(&Apache::response::repetition());
     }
     pop(@Apache::lonxml::namespace);
+    pop(@Apache::response::custom_answer);
+    pop(@Apache::response::custom_answer_type);
     &Apache::lonxml::deregister('Apache::response',('answer'));
     &Apache::response::end_response();
     return $result;
 }
 
+sub format_prior_response_custom {
+    my ($mode,$answer) =@_;
+    return '<span class="LC_prior_custom">'.
+	    &HTML::Entities::encode($answer,'"<>&').'</span>';
+}
 
 sub start_mathresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $id = &Apache::response::start_response($parstack,$safeeval);
     push(@Apache::lonxml::namespace,'mathresponse');
     my $result;
-    undef($Apache::response::custom_answer);
+    @Apache::response::custom_answer=();
+    @Apache::response::custom_answer_type=();
     &Apache::lonxml::register('Apache::response',('answer'));
     if ($target eq 'web') {
   	if (  &Apache::response::show_answer() ) {
@@ -474,18 +489,15 @@ sub start_mathresponse {
 					   'cas',
 					   ['maxima'],
 					   $token);
-	$result.=&Apache::edit::text_arg('Algebra System:',
-					 'cas',$token);
 	$result.=&Apache::edit::text_arg('Argument Array:',
 					 'args',$token);
 	$result.=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
 	my $constructtag;
 	$constructtag=&Apache::edit::get_new_args($token,$parstack,
-						  $safeeval,'answerdisplay');
+						  $safeeval,'answerdisplay','cas','args');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     } elsif ($target eq 'answer' || $target eq 'grade') {
 	&Apache::response::reset_params();
@@ -511,10 +523,12 @@ sub end_mathresponse {
 	    $Apache::lonhomework::results{"resource.$part.$id.submission"}=
 		$response;
 	    my $error;
-	    ${$safeeval->varglob('LONCAPA::mathresponse_submission')}=
-		$response;
-	    
-	    my $award = &Apache::run::run('{ my $submission=$LONCAPA::mathresponse_submission;'.$Apache::response::custom_answer.'}',$safeeval);
+	    my $award;
+	    my $cas = &Apache::lonxml::get_param('cas',$parstack,$safeeval);
+            if ($cas eq 'maxima') {
+                my $args = [&Apache::lonxml::get_param_var('args',$parstack,$safeeval)];
+                $award=&Apache::lonmaxima::maxima_run($Apache::response::custom_answer[-1],$response,$args);
+            }
 	    if (!&Apache::inputtags::valid_award($award)) {
 		$error = $award;
 		$award = 'ERROR';
@@ -528,25 +542,59 @@ sub end_mathresponse {
 	    }
 	}
     }
+    if ($target eq 'web') {
+	&setup_prior_tries_hash(\&format_prior_response_math);
+    }
+
     pop(@Apache::lonxml::namespace);
+    pop(@Apache::response::custom_answer);
+    pop(@Apache::response::custom_answer_type);
     &Apache::lonxml::deregister('Apache::response',('answer'));
     &Apache::response::end_response();
     return $result;
 }
 
+sub format_prior_response_math {
+    my ($mode,$answer) =@_;
+    return '<span class="LC_prior_math">'.
+	    &HTML::Entities::encode($answer,'"<>&').'</span>';
+}
+
+sub implicit_multiplication {
+    my ($expression)=@_;
+# Escape scientific notation, so 3e8 does not become 3*e*8
+# 3e8 -> 3&8; 3e-8 -> 3&-8; 3E+8 -> e&+8
+    $expression=~s/(\d+)e([\+\-]*\d+)/$1\&\($2\)/gsi;
+# 3x10^8 -> 3&8; 3*10^-8 -> 3&-8
+    $expression=~s/(\d+)(?:x|\*)10(?:\^|\*\*)([\+\-]*\d+)/$1\&\($2\)/gsi;
+# Fill in multiplication signs
+# a b -> a*b;3 b -> 3*b;3 4 -> 3*4
+    $expression=~s/(\w)\s+(\w)/$1\*$2/gs;
+# )( -> )*(; ) ( -> )*(
+    $expression=~s/\)\s*\(/\)\*\(/gs;
+# 3a -> 3*a; 3( -> 3*(; 3 ( -> 3*(; 3A -> 3*A
+    $expression=~s/(\d)\s*([a-zA-Z\(])/$1\*$2/gs;
+# a ( -> a*(
+    $expression=~s/(\w)\s+\(/$1\*\(/gs;
+# )a -> )*a; )3 -> )*3; ) 3 -> )*3
+    $expression=~s/\)\s*(\w)/\)\*$1/gs;
+# 3&8 -> 3e8; 3&-4 -> 3e-4
+    $expression=~s/(\d+)\&\(([\+\-]*\d+)\)/$1e$2/gs;
+    return $expression;
+}
 
 sub start_answer {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
-    $Apache::response::custom_answer=
-	&Apache::lonxml::get_all_text_unbalanced("/answer",$parser);
-    $Apache::response::custom_answer_type=
-	lc(&Apache::lonxml::get_param('type',$parstack,$safeeval));
-    $Apache::response::custom_answer_type =~ s/\s+//g;
+    push(@Apache::response::custom_answer,
+	&Apache::lonxml::get_all_text_unbalanced("/answer",$parser));
+    push(@Apache::response::custom_answer_type,
+	lc(&Apache::lonxml::get_param('type',$parstack,$safeeval)));
+    $Apache::response::custom_answer_type[-1] =~ s/\s+//g;
     if ($target eq "edit" ) {
 	$result=&Apache::edit::tag_start($target,$token,'Answer algorithm');
 	$result.=&Apache::edit::editfield($token->[1],
-					  $Apache::response::custom_answer,
+					  $Apache::response::custom_answer[-1],
 					  '',80,4);
     } elsif ( $target eq "modified" ) {
 	$result=$token->[4].&Apache::edit::modifiedfield('/answer',$parser);
@@ -627,7 +675,6 @@ sub start_responseparam {
 	}
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     } elsif ($target eq 'grade' || $target eq 'answer' || $target eq 'web' ||
 	     $target eq 'tex' || $target eq 'analyze' ) {
@@ -665,7 +712,7 @@ sub setup_params {
     if ($env{'request.state'} eq 'construct') { return; }
     my %paramlist=();
     foreach my $key (keys(%Apache::lonnet::packagetab)) {
-	if ($key =~ /^$tag/) {
+	if ($key =~ /^\Q$tag\E/) {
 	    my ($package,$name) = split(/&/,$key);
 	    $paramlist{$name}=1;
 	}
@@ -972,7 +1019,17 @@ sub pick_foil_for_concept {
 	$Apache::response::conceptgroup{'names'};
 
 }
-
+#------------------------------------------------------------
+#
+#  Get a parameter associated with a problem.
+# Parameters:
+#  $id        - the id of the paramater, either a part id, 
+#               or a partid and responspe id joined by _
+#  $name      - Name of the parameter to fetch
+#  $default   - Default value for the paramter.
+#
+#  
+#
 sub get_response_param {
     my ($id,$name,$default)=@_;
     my $parameter;
@@ -997,7 +1054,13 @@ sub submitted {
     if ($who eq 'scantron') { return 0; }
     # if the Submit Answer button for this particular part was pressed
     my $partid=$Apache::inputtags::part;
-    if (defined($env{'form.submit_'.$partid})) { return 1; }
+    if ($env{'form.submitted'} eq "part_$partid") {
+	return 1;
+    }
+    if ($env{'form.submitted'} eq "yes"
+	&& defined($env{'form.submit_'.$partid})) {
+	return 1;
+    }
     # Submit All button on a .page was pressed
     if (defined($env{'form.all_submit'})) { return 1; }
     # otherwise no submission occured
@@ -1057,6 +1120,33 @@ sub check_status {
     return 2;
 }
 
+sub setup_prior_tries_hash {
+    my ($func,$data) = @_;
+    my $part = $Apache::inputtags::part;
+    my $id   = $Apache::inputtags::response[-1];	
+    foreach my $i (1..$Apache::lonhomework::history{'version'}) {
+	my $sub_key   = "$i:resource.$part.$id.submission";
+	next if (!exists($Apache::lonhomework::history{$sub_key}));
+	my @other_data;
+	foreach my $datum (@{ $data }) {
+	    if (ref($datum)) {
+		push(@other_data,$datum);
+	    } else {
+		my $info_key = "$i:resource.$part.$id.$datum";
+		push(@other_data,$Apache::lonhomework::history{$info_key});
+	    }
+	}
+
+	my $output =
+	    &$func('grade',
+		   $Apache::lonhomework::history{$sub_key},
+		   \@other_data);
+	if (defined($output)) {
+	    $Apache::inputtags::submission_display{$sub_key} = $output;
+	}
+    }
+}
+
 1;
 __END__
  
