@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.63 2007/03/20 15:39:11 albertel Exp $
+# $Id: lonpickcourse.pm,v 1.63.2.1 2007/06/01 18:07:47 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -363,9 +363,9 @@ $multelement
     if ($domainselectform) {
         $output .= $lt{'cdo'}.': '.$domainselectform.'<br />'."\n";
     }
-    if ($typeselectform) {
-        $output .= $lt{'cog'}.': '.$typeselectform.'<br />'."\n";
-    }
+#    if ($typeselectform) {
+#        $output .= $lt{'cog'}.': '.$typeselectform.'<br />'."\n";
+#    }
     if ($instcodeform) {
         $output .= $lt{'cin'}.': '.$instcodeform.'<br />'."\n";
     }
