@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.95 2006/12/06 22:22:37 albertel Exp $
+# $Id: lonpreferences.pm,v 1.104 2007/05/13 22:04:06 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -280,6 +280,8 @@ ENDVCSCREEN
 ################################################################
 sub rolesprefchanger {
     my $r = shift;
+    my $role    = ($env{'user.adv'} ? 'Role' : 'Course');
+    my $lc_role = ($env{'user.adv'} ? 'role' : 'course');
     my $user       = $env{'user.name'};
     my $domain     = $env{'user.domain'};
     my %userenv = &Apache::lonnet::get
@@ -314,8 +316,8 @@ sub rolesprefchanger {
         $roles_check_list .=
 	    &Apache::loncommon::start_data_table().
 	    &Apache::loncommon::start_data_table_header_row().
-	    "<th>".&mt('Freeze Role')."</th>".
-	    "<th>".&mt('Role')."</td>".
+	    "<th>".&mt('Freeze '.$role)."</th>".
+	    "<th>".&mt($role)."</td>".
 	    &Apache::loncommon::end_data_table_header_row().
 	    "\n";
 	my $count;
@@ -339,17 +341,17 @@ sub rolesprefchanger {
     }
 
     $r->print('
-<p>'.&mt('Some LON-CAPA users have a long list of roles. The Recent Roles Hotlist feature keeps track of the last N roles which have been visited and places a table of these at the top of the roles page. People with very few roles should leave this feature disabled.').'
+<p>'.&mt('Some LON-CAPA users have a long list of '.$lc_role.'s. The Recent '.$role.'s Hotlist feature keeps track of the last N '.$lc_role.'s which have been visited and places a table of these at the top of the '.$lc_role.'s page. People with very few '.$lc_role.'s should leave this feature disabled.').'
 </p>
 <form name="prefs" action="/adm/preferences" method="POST">
 <input type="hidden" name="action" value="verify_and_change_rolespref" />
-<br /><label>'.&mt('Enable Recent Roles Hotlist:').'
+<br /><label>'.&mt('Enable Recent '.$role.'s Hotlist:').'
 <input type="checkbox" '.$checked.' name="recentroles" value="true" /></label>
-<br />'.&mt('Number of roles in Hotlist:').'
+<br />'.&mt('Number of '.$role.'s in Hotlist:').'
 <select name="recentrolesn" size="1">
 '.$options.'
 </select>
-<p>'.&mt('This list below can be used to <q>freeze</q> roles on your screen. Those marked as frozen will not be removed from the list, even if they have not been used recently.').'
+<p>'.&mt('This list below can be used to <q>freeze</q> '.$lc_role.'s on your screen. Those marked as frozen will not be removed from the list, even if they have not been used recently.').'
 </p>
 '.$roles_check_list.'
 <br />
@@ -389,6 +391,7 @@ sub rolespref_get_role_text {
 
 sub verify_and_change_rolespref {
     my $r = shift;
+    my $role = ($env{'user.adv'} ? 'Role' : 'Course');
     my $user       = $env{'user.name'};
     my $domain     = $env{'user.domain'};
 # Recent Roles Hotlist Flag
@@ -398,18 +401,18 @@ sub verify_and_change_rolespref {
     if ($hotlist_flag) {
         &Apache::lonnet::put('environment',{'recentroles' => $hotlist_flag});
         &Apache::lonnet::appenv('environment.recentroles' => $hotlist_flag);
-        $message=&mt('Recent Roles Hotlist is Enabled');
+        $message=&mt('Recent '.$role.'s Hotlist is Enabled');
     } else {
         &Apache::lonnet::del('environment',['recentroles']);
         &Apache::lonnet::delenv('environment\.recentroles');
-        $message=&mt('Recent Roles Hotlist is Disabled');
+        $message=&mt('Recent '.$role.'s Hotlist is Disabled');
     }
     if ($hotlist_n) {
         &Apache::lonnet::put('environment',{'recentrolesn' => $hotlist_n});
         &Apache::lonnet::appenv('environment.recentrolesn' => $hotlist_n);
         if ($hotlist_flag) {
             $message.="<br />".
-		&mt('Display [_1] Most Recent Roles',$hotlist_n)."\n";
+		&mt('Display [_1] Most Recent '.$role.'s',$hotlist_n)."\n";
         }
     }
 
@@ -431,7 +434,7 @@ sub verify_and_change_rolespref {
 # Unset any roles that were previously frozen but aren't in list
     foreach my $role_key (sort(keys(%recent_roles))) {
         if (($frozen_roles{$role_key}) && (!exists($freeze{$role_key}))) {
-	    $message .= "<br />".&mt('Unfreezing Role: [_1]',$role_text{$role_key})."\n";
+	    $message .= "<br />".&mt('Unfreezing '.$role.': [_1]',$role_text{$role_key})."\n";
 	    &Apache::lonhtmlcommon::store_recent('roles',$role_key,' ',0);
         }
     }
@@ -439,7 +442,7 @@ sub verify_and_change_rolespref {
 # Freeze selected roles
     foreach my $role_key (@freeze_list) {
         if (!$frozen_roles{$role_key}) {
-             $message .= "<br />".&mt('Freezing Role: [_1]',$role_text{$role_key})."\n";
+             $message .= "<br />".&mt('Freezing '.$role.': [_1]',$role_text{$role_key})."\n";
              &Apache::lonhtmlcommon::store_recent('roles',
                                           $role_key,' ',1);
         }
@@ -512,38 +515,260 @@ $message
 ENDVCSCREEN
 }
 
+################################################################
+#                     Icon Subroutines                         #
+################################################################
+sub iconchanger {
+    my $r = shift;
+    my $user       = $env{'user.name'};
+    my $domain     = $env{'user.domain'};
+    my %userenv = &Apache::lonnet::get
+        ('environment',['icons']);
+    my $iconic='checked="checked"';
+    my $classic='';
+    my $onlyicon='';
+    if ($userenv{'icons'} eq 'classic') {
+       $classic='checked="checked"';
+       $iconic='';
+    }
+    if ($userenv{'icons'} eq 'iconsonly') {
+       $onlyicon='checked="checked"';
+       $iconic='';
+    }
+    my $useicons=&mt('Use icons and text');
+    my $usebuttons=&mt('Use buttons and text');
+    my $useicononly=&mt('Use icons only');
+    my $change=&mt('Change');
+    $r->print(<<ENDSCREEN);
+<form name="prefs" action="/adm/preferences" method="post">
+<input type="hidden" name="action" value="verify_and_change_icons" />
+<label><input type="radio" name="menumode" value="iconic" $iconic /> $useicons</label><br />
+<label><input type="radio" name="menumode" value="classic" $classic /> $usebuttons</label><br />
+<label><input type="radio" name="menumode" value="iconsonly" $onlyicon /> $useicononly</label><br />
+<input type="submit" value="$change" />
+</form>
+ENDSCREEN
+}
+
+sub verify_and_change_icons {
+    my $r = shift;
+    my $user       = $env{'user.name'};
+    my $domain     = $env{'user.domain'};
+    my $newicons  = $env{'form.menumode'};
+
+    &Apache::lonnet::put('environment',{'icons' => $newicons});
+    &Apache::lonnet::appenv('environment.icons' => $newicons);
+    $r->print(&mt('Set menu mode to [_1].',$newicons));
+}
+
 ################################################################
 #         Message Forward                                      #
 ################################################################
 
 sub msgforwardchanger {
-    my $r = shift;
+    my ($r,$message) = @_;
     my $user       = $env{'user.name'};
     my $domain     = $env{'user.domain'};
-    my %userenv = &Apache::lonnet::get('environment',['msgforward','notification','critnotification']);
+    my %userenv = &Apache::lonnet::get('environment',['msgforward','notification','critnotification','notifywithhtml']);
     my $msgforward=$userenv{'msgforward'};
-    my $notification=$userenv{'notification'};
-    my $critnotification=$userenv{'critnotification'};
+    my %lt = &Apache::lonlocal::texthash(
+                                          all   => 'All',
+                                          crit  => 'Critical only',
+                                          reg   => 'Non-critical only',
+                                          foad  => 'Forwarding Address(es)',
+                                          mnot  => 'Message Notification Email Address(es)',
+                                          chg   => 'Change',
+                                          email => 'The e-mail address entered in row ',
+                                          notv => 'is not a valid e-mail address',
+                                          toen => "To enter multiple addresses, enter one address at a time, click 'Change' and then add the next one", 
+                                          prme => 'Back to preferences menu',
+                                        );
     my $forwardingHelp = Apache::loncommon::help_open_topic("Prefs_Forwarding",
 							    "What are forwarding ".
 							    "and notification ".
 							    "addresses");
     my $criticalMessageHelp = Apache::loncommon::help_open_topic("Course_Critical_Message",
 								 "What are critical messages");
+    my @allow_html = split(/,/,$userenv{'notifywithhtml'});
+    my %allnot = &get_notifications(\%userenv);
+    my $validatescript = &Apache::lonhtmlcommon::javascript_valid_email();
+    my $jscript = qq|
+<script type="text/javascript">
+function validate() {
+    for (var i=0; i<document.prefs.numnotify.value; i++) {
+        var checkaddress = 0;
+        var addr = document.prefs.elements['address_'+i].value;
+        var rownum = i+1;
+        if (i < document.prefs.numnotify.value-1) {
+            if (document.prefs.elements['modify_notify_'+i].checked) {
+                checkaddress = 1;
+            }
+        } else {
+            if (document.prefs.elements['add_notify_'+i].checked == true) { 
+                checkaddress = 1;
+            }
+        }
+        if (checkaddress == 1)  {
+            var addr = document.prefs.elements['address_'+i].value;
+            if (validmail(document.prefs.elements['address_'+i]) == false) {
+                var multimsg = '';
+                if (addr.indexOf(",") >= 0) {
+                    multimsg = "\\n($lt{'toen'}).";
+                }
+                alert("$lt{'email'} "+rownum+": '"+addr+"' $lt{'notv'}."+multimsg);
+                return;
+            }
+        }
+    }
+    document.prefs.submit();
+}
 
+function address_changes (adnum) {
+     if (!document.prefs.elements['del_notify_'+adnum].checked) { 
+         document.prefs.elements['modify_notify_'+adnum].checked = true;
+     }   
+}
+
+function new_address(adnum) {
+     document.prefs.elements['add_notify_'+adnum].checked = true;
+}
+
+function delete_address(adnum) {
+     if (document.prefs.elements['del_notify_'+adnum].checked) {
+          document.prefs.elements['modify_notify_'+adnum].checked = false;
+     }
+}
+
+function modify_address(adnum) {
+    if (document.prefs.elements['modify_notify_'+adnum].checked) {
+        document.prefs.elements['del_notify_'+adnum].checked = false;
+    }
+} 
+
+$validatescript
+</script>
+|;
     $r->print(<<ENDMSG);
-$forwardingHelp <br />
+$jscript
+$message
+$forwardingHelp
 <form name="prefs" action="/adm/preferences" method="post">
 <input type="hidden" name="action" value="verify_and_change_msgforward" />
-New Forwarding Address(es) (<tt>user:domain,user:domain,...</tt>):
+$lt{'foad'} (<tt>user:domain,user:domain,...</tt>):
 <input type="text" size="40" value="$msgforward" name="msgforward" /><hr />
-New Message Notification Email Address(es) (<tt>joe\@doe.com,jane\@doe.edu,...</tt>):
-<input type="text" size="40" value="$notification" name="notification" /><hr />
-New Critical Message Notification Email Address(es) (<tt>joe\@doe.com,jane\@doe.edu,...</tt>):
-<input type="text" size="40" value="$critnotification" name="critnotification" />$criticalMessageHelp<hr />
-<input type="submit" value="Change" />
-</form>
+$criticalMessageHelp
+$lt{'mnot'} (<tt>joe\@doe.com</tt>):<br />
 ENDMSG
+    my @sortforwards = sort (keys(%allnot));
+    my $output = &Apache::loncommon::start_data_table().
+                 &Apache::loncommon::start_data_table_header_row().
+                 '<th>&nbsp;</th>'.
+                 '<th>'.&mt('Action').'</th>'.
+                 '<th>'.&mt('Notification address').'</th><th>'.
+                 &mt('Types of message to forward to this address').'</th><th>'.
+                 &mt('Excerpt retains HTML tags in message').'</th>'.
+                 &Apache::loncommon::end_data_table_header_row();
+    my $num = 0;
+    my $counter = 1;
+    foreach my $item (@sortforwards) {
+        $output .= &Apache::loncommon::start_data_table_row().
+                   '<td><b>'.$counter.'</b></td>'.
+                   '<td><span class="LC_nobreak"><label>'.
+                   '<input type="checkbox" name="modify_notify_'.
+                   $num.'" onclick="javscript:modify_address('."'$num'".')" />'.
+                   &mt('Modify').'</label></span>&nbsp;&nbsp; '.
+                   '<span class="LC_nobreak"><label>'.
+                   '<input type="checkbox" name="del_notify_'.$num.
+                   '" onclick="javscript:delete_address('."'$num'".')" />'.
+                   &mt('Delete').'</label></span></td>'.
+                   '<td><input type="text" value="'.$item.'" name="address_'.
+                   $num.'" onFocus="javascript:address_changes('."'$num'".
+                   ')" /></td><td>';
+        my %chk;
+        if (defined($allnot{$item}{'crit'})) {
+            if (defined($allnot{$item}{'reg'})) {
+                $chk{'all'} = 'checked="checked" ';
+            } else {
+                $chk{'crit'} = 'checked="checked" ';
+            }
+        } else {
+            $chk{'reg'} = 'checked="checked" ';
+        }
+        foreach my $type ('all','crit','reg') {
+            $output .= '<span class="LC_nobreak"><label>'.
+                       '<input type="radio" name="notify_type_'.$num. 
+                       '" value="'.$type.'" '.$chk{$type}.
+                       ' onchange="javascript:address_changes('."'$num'".')" />'.
+                       $lt{$type}.'</label></span>&nbsp;';
+        }
+        my $htmlon = '';
+        my $htmloff = '';
+        if (grep/^\Q$item\E/,@allow_html) {
+            $htmlon = 'checked="checked" '; 
+        } else {
+            $htmloff = 'checked="checked" ';
+        }
+        $output .= '</td><td><label><input type="radio" name="html_'.$num.
+                   '" value="1" '.$htmlon.
+                   ' onchange="javascript:address_changes('."'$num'".')" />'.
+                   &mt('Yes').'</label>&nbsp;'.
+                   '<label><input type="radio" name="html_'.$num.'" value="0" '.
+                   $htmloff. ' onchange="javascript:address_changes('."'$num'".
+')" />'.
+                   &mt('No').'</label></td>'.
+                   &Apache::loncommon::end_data_table_row();
+        $num ++;
+        $counter ++;
+    }
+    my %defchk = (
+                   all => 'checked="checked" ',
+                   crit => '',
+                   reg => '',
+                 );
+    $output .= &Apache::loncommon::start_data_table_row().
+               '<td><b>'.$counter.'</b></td>'.
+               '<td><span class="LC_nobreak"><label>'.
+               '<input type="checkbox" name="add_notify_'.$num.
+               '" value="1" />'.&mt('Add new address').'</label></span></td>'.
+               '<td><input type="text" value="" name="address_'.$num.
+               '" onFocus="javascript:new_address('."'$num'".')" /></td><td>';
+    foreach my $type ('all','crit','reg') {
+        $output .= '<span class="LC_nobreak"><label>'.
+                   '<input type="radio" name="notify_type_'.$num.
+                   '" value="'.$type.'" '.$defchk{$type}.'/>'.
+                   $lt{$type}.'</label></span>&nbsp;';
+    }
+    $output .= '</td><td><label><input type="radio" name="html_'.$num.
+               '" value="1" />'.&mt('Yes').'</label>&nbsp;'.
+               '<label><input type="radio" name="html_'.$num.'" value="0" '.
+               ' checked="checked" />'.
+               &mt('No').'</label></td>'.
+               &Apache::loncommon::end_data_table_row().
+               &Apache::loncommon::end_data_table();
+    $num ++;
+    $r->print($output);
+    $r->print(qq|
+<hr />
+<input type="hidden" name="numnotify" value="$num" />
+<input type="button" value="$lt{'chg'}" onclick="javascript:validate()" />
+<input type="button" value="$lt{'prme'}" onclick="location.href='/adm/preferences'" />
+</form>
+|);
+
+}
+
+sub get_notifications {
+    my ($userenv) = @_;
+    my %allnot;
+    my @critnot = split(/,/,$userenv->{'critnotification'});
+    my @regnot = split(/,/,$userenv->{'notification'});
+    foreach my $item (@critnot) {
+        $allnot{$item}{crit} = 1;
+    }
+    foreach my $item (@regnot) {
+        $allnot{$item}{reg} = 1;
+    }
+    return %allnot;
 }
 
 sub verify_and_change_msgforward {
@@ -560,7 +785,7 @@ sub verify_and_change_msgforward {
 	    if (&Apache::lonnet::homeserver($msuser,$msdomain) ne 'no_host') {
                $newscreen.=$msuser.':'.$msdomain.',';
 	   } else {
-               $message.='No such user: '.$msuser.':'.$msdomain.'<br>';
+               $message.= &mt('No such user: ').$msuser.':'.$msdomain.'<br>';
            }
         }
     }
@@ -568,37 +793,84 @@ sub verify_and_change_msgforward {
     if ($newscreen) {
         &Apache::lonnet::put('environment',{'msgforward' => $newscreen});
         &Apache::lonnet::appenv('environment.msgforward' => $newscreen);
-        $message.='Set new message forwarding to '.$newscreen.'<br />';
+        $message .= &mt('Set message forwarding to: ').'<tt>'.$newscreen.
+                    '</tt><br />';
     } else {
         &Apache::lonnet::del('environment',['msgforward']);
         &Apache::lonnet::delenv('environment\.msgforward');
-        $message.='Reset message forwarding<br />';
+        $message.= &mt("Set message forwarding to 'off'.").'<br />';
     }
-    my $notification=$env{'form.notification'};
+    my $critnotification;
+    my $notification;
+    my $notify_with_html;
+    my $lastnotify = $env{'form.numnotify'}-1;
+    my $totaladdresses = 0;
+    for (my $i=0; $i<$env{'form.numnotify'}; $i++) {
+        if ((!defined($env{'form.del_notify_'.$i})) &&  
+           ((($i==$lastnotify) && ($env{'form.add_notify_'.$lastnotify} == 1)) ||
+            ($i<$lastnotify))) {
+            if (defined($env{'form.address_'.$i})) {
+                if ($env{'form.notify_type_'.$i} eq 'all') {
+                    $critnotification .= $env{'form.address_'.$i}.',';
+                    $notification .= $env{'form.address_'.$i}.',';
+                } elsif ($env{'form.notify_type_'.$i} eq 'crit') {
+                    $critnotification .= $env{'form.address_'.$i}.',';
+                } elsif ($env{'form.notify_type_'.$i} eq 'reg') {
+                    $notification .= $env{'form.address_'.$i}.','; 
+                }
+                if ($env{'form.html_'.$i} eq '1') {
+		    $notify_with_html .= $env{'form.address_'.$i}.',';       	
+                }
+                $totaladdresses ++;
+            }
+        }
+    }
+    $critnotification =~ s/,$//;
+    $critnotification=~s/\s//gs;
+    $notification =~ s/,$//;
     $notification=~s/\s//gs;
+    $notify_with_html =~ s/,$//;
+    $notify_with_html =~ s/\s//gs;
     if ($notification) {
         &Apache::lonnet::put('environment',{'notification' => $notification});
         &Apache::lonnet::appenv('environment.notification' => $notification);
-        $message.='Set message notification address to '.$notification.'<br />';
+        $message.=&mt('Set non-critical message notification address(es) to: ').'<tt>'.$notification.'</tt><br />';
     } else {
         &Apache::lonnet::del('environment',['notification']);
         &Apache::lonnet::delenv('environment\.notification');
-        $message.='Reset message notification<br />';
+        $message.=&mt("Non-critical message notification set to 'off'.").'<br />';
     }
-    my $critnotification=$env{'form.critnotification'};
-    $critnotification=~s/\s//gs;
     if ($critnotification) {
         &Apache::lonnet::put('environment',{'critnotification' => $critnotification});
         &Apache::lonnet::appenv('environment.critnotification' => $critnotification);
-        $message.='Set critical message notification address to '.$critnotification;
+        $message.=&mt('Set critical message notification address(es) to: ').'<tt>'.$critnotification.'</tt><br />';
     } else {
         &Apache::lonnet::del('environment',['critnotification']);
         &Apache::lonnet::delenv('environment\.critnotification');
-        $message.='Reset critical message notification<br />';
+        $message.=&mt("Critical message notification set to 'off'.").'<br />';
     }
-    $r->print(<<ENDVCMSG);
-$message
-ENDVCMSG
+    if ($critnotification || $notification) {
+        if ($notify_with_html) {
+            &Apache::lonnet::put('environment',{'notifywithhtml' => $notify_with_html});
+            &Apache::lonnet::appenv('environment.notifywithhtml' => $notify_with_html);
+            $message.=&mt('Set address(es) to receive excerpts with html retained: ').'<tt>'.$notify_with_html.'</tt>';
+        } else {
+            &Apache::lonnet::del('environment',['notifywithhtml']);
+            &Apache::lonnet::delenv('environment\.notifywithhtml');
+            if ($totaladdresses == 1) {
+                $message.=&mt("Set notification address to receive excerpts with html stripped.");
+            } else {
+                $message.=&mt("Set all notification addresses to receive excerpts with html stripped.");
+            }
+        }
+    } else {
+        &Apache::lonnet::del('environment',['notifywithhtml']);
+        &Apache::lonnet::delenv('environment\.notifywithhtml');
+    }
+    if ($message) {
+        $message .= '<br /><hr />';
+    }
+    &msgforwardchanger($r,$message);
 }
 
 ################################################################
@@ -842,20 +1114,29 @@ sub jscript_send {
 
 sub client_form {
     my ($caller,$hexkey,$currentpass,$defdom) = @_;
+    my %lt=&Apache::lonlocal::texthash(
+                'email' => 'EMail Address',
+                'username' => 'Username',
+                'domain' => 'Domain',
+                'currentpass' => 'Current Password',
+                'newpass' => 'New Password',
+                'confirmpass' => 'Confirm Password',
+                'changepass' => 'Change Password');
+
     my $output = qq|
 <form name="client" >
 <table>
 |;
     if ($caller eq 'reset_by_email') {
         $output .= qq|
-<tr><td align="right"> E-mail address:                        </td>
-    <td><input type="text" name="email" size="15" /> </td></tr>
-<tr><td align="right"> Username:                        </td>
+<tr><td class="LC_preferences_labeltext"><label for="email">$lt{'email'}</label>:</td>
+    <td><input type="text" name="email" size="30" /> </td></tr>
+<tr><td class="LC_preferences_labeltext"><label for="uname">$lt{'username'}</label>:</td>
     <td>
-     <input type="text" name="uname" size="10" />
+     <input type="text" name="uname" size="15" />
      <input type="hidden" name="currentpass" value="$currentpass" />
     </td></tr>
-<tr><td align="right"> Domain:                               </td>
+<tr><td class="LC_preferences_labeltext"><label for="udom">$lt{'udom'}</label>:</td>
     <td>
 |;
         $output .= &Apache::loncommon::select_dom_form($defdom,'udom').'
@@ -864,17 +1145,17 @@ sub client_form {
 ';
     } else {
         $output .= qq|
-<tr><td align="right"> Current password:                      </td>
+<tr><td class="LC_preferences_labeltext"><label for="currentpass">$lt{'currentpass'}</label></td>
     <td><input type="password" name="currentpass" size="10"/> </td></tr>
 |;
     }
     $output .= <<"ENDFORM";
-<tr><td align="right"> New password:                          </td>
+<tr><td class="LC_preferences_labeltext"><label for="newpass_1">$lt{'newpass'}</label></td>
     <td><input type="password" name="newpass_1" size="10"  /> </td></tr>
-<tr><td align="right"> Confirm password:                      </td>
+<tr><td class="LC_preferences_labeltext"><label for="newpass_2">$lt{'confirmpass'}</label></td>
     <td><input type="password" name="newpass_2" size="10"  /> </td></tr>
 <tr><td colspan="2" align="center">
-    <input type="button" value="Change Password" onClick="send();">
+    <input type="button" value="$lt{'changepass'}" onClick="send();">
 </table>
 <input type="hidden" name="ukey_cpass"  value="$hexkey->{'ukey_cpass'}" />
 <input type="hidden" name="lkey_cpass"  value="$hexkey->{'lkey_cpass'}" />
@@ -925,14 +1206,14 @@ sub verify_and_change_password {
         if ($user ne '' && $domain ne '') {
             $homeserver = &Apache::lonnet::homeserver($user,$domain);
             if ($homeserver eq 'no_host') {
-        &passwordchanger($r,"<p>\n<font color='#ff0000'>ERROR</font>".
-                         "Invalid username and/or domain .\n</p>",
+        &passwordchanger($r,"<p>\n<span class='LC_error'>".
+                         &mt("Invalid username and/or domain")."</span>\n</p>",
                          $caller,$mailtoken);
                 return 1;
             }
         } else {
-            &passwordchanger($r,"<p>\n<font color='#ff0000'>ERROR</font>".
-                             "Username and Domain were blank.\n</p>",
+            &passwordchanger($r,"<p>\n<span class='LC_error'>".
+                             &mt("Username and domain were blank")."</span>\n</p>",
                              $caller,$mailtoken);
             return 1;
         }
@@ -945,8 +1226,9 @@ sub verify_and_change_password {
     # Check for authentication types that allow changing of the password.
     if ($currentauth !~ /^(unix|internal):/) {
         if ($caller eq 'reset_by_email') {
-            &passwordchanger($r,"<p>\n<font color='#ff0000'>ERROR</font>".
-                             "Authentication type for this user can not be changed by this mechanism..\n</p>",
+            &passwordchanger($r,"<p>\n<span class='LC_error'>".
+                             &mt("Authentication type for this user can not be changed by this mechanism").
+                             "</span>\n</p>",
                               $caller,$mailtoken);
             return 1;
         } else {
@@ -962,8 +1244,9 @@ sub verify_and_change_password {
     unless (defined($currentpass) && 
 	    defined($newpass1)    && 
 	    defined($newpass2)    ){
-	&passwordchanger($r,"<p>\n<font color='#ff0000'>ERROR</font>".
-			 "One or more password fields were blank.\n</p>",$caller,$mailtoken);
+	&passwordchanger($r,"<p>\n<span class='LC_error'>".
+			 &mt("One or more password fields were blank").
+                         "</span>\n</p>",$caller,$mailtoken);
 	return;
     }
     # Get the keys
@@ -975,10 +1258,10 @@ sub verify_and_change_password {
         if ($caller eq 'reset_by_email') {
             $tryagain_text = &mt('Please try again later.');
         }
+        my $unable=&mt("Unable to retrieve saved token for password decryption");
 	$r->print(<<ENDERROR);
 <p>
-<font color="#ff0000">ERROR:</font> Unable to retrieve stored token for
-password decryption.  $tryagain_text
+<span class="LC_error">$unable.  $tryagain_text</span>
 </p>
 ENDERROR
         # Probably should log an error here
@@ -994,24 +1277,24 @@ ENDERROR
         my %data = &Apache::lonnet::tmpget($mailtoken);
         if ($currentpass ne $data{'temppasswd'}) {
             &passwordchanger($r,
-                         '<font color="#ff0000">ERROR:</font>'.
-                         'Could not verify current authentication.  '.
-                         'Please try again.',$caller,$mailtoken);
+                         '<span class="LC_error">'.
+                         &mt('Could not verify current authentication').'.  '.
+                         &mt('Please try again').'.</span>',$caller,$mailtoken);
             return 1;
         }
     } 
     if ($newpass1 ne $newpass2) {
 	&passwordchanger($r,
-			 '<font color="#ff0000">ERROR:</font>'.
-			 'The new passwords you entered do not match.  '.
-			 'Please try again.',$caller,$mailtoken);
+			 '<span class="LC_error">'.
+			 &mt('The new passwords you entered do not match').'.  '.
+			 &mt('Please try again').'.</span>',$caller,$mailtoken);
 	return 1;
     }
     if (length($newpass1) < 7) {
 	&passwordchanger($r,
-			 '<font color="#ff0000">ERROR:</font>'.
-			 'Passwords must be a minimum of 7 characters long.  '.
-			 'Please try again.',$caller,$mailtoken);
+			 '<span class="LC_error">'.
+			 &mt('Passwords must be a minimum of 7 characters long').'.  '.
+			 &mt('Please try again').'</span>.',$caller,$mailtoken);
 	return 1;
     }
     #
@@ -1022,14 +1305,14 @@ ENDERROR
     }
     if ($badpassword) {
 	# I can't figure out how to enter bad characters on my browser.
-	my $errormessage = <<"ENDERROR";
-<font color="#ff0000">ERROR:</font>
-The password you entered contained illegal characters.<br />
-Valid characters are: space and <br />
+	my $errormessage ='<span class="LC_error">'.
+           &mt('The password you entered contained illegal characters').'.<br />'.
+           &mt('Valid characters are').(<<"ENDERROR");
+: space and <br />
 <pre>
 !&quot;\#$%&amp;\'()*+,-./0123456789:;&lt;=&gt;?\@
 ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_\`abcdefghijklmnopqrstuvwxyz{|}~
-</pre>
+</pre></span>
 ENDERROR
         &passwordchanger($r,$errormessage,$caller,$mailtoken);
         return 1;
@@ -1040,15 +1323,11 @@ ENDERROR
 	($user,$domain,$currentpass,$newpass1,$homeserver,$caller);
     # Inform the user the password has (not?) been changed
     if ($result =~ /^ok$/) {
-	$r->print(<<"ENDTEXT");
-<h3>The password for $user was successfully changed</h3>
-ENDTEXT
+	$r->print("<h3>".&mt('The password for [_1] was successfully changed',$user)."</h3>");
     } else {
 	# error error: run in circles, scream and shout
-        $r->print(<<ENDERROR);
-<h3><font color="#ff0000">The password for $user was not changed</font></h3>
-Please make sure your old password was entered correctly.
-ENDERROR
+        $r->print("<h3><span class='LC_error'>".&mt("The password for [_1] was not changed",$user)."</span></h3>".
+                  &mt('Please make sure your old password was entered correctly').'.');
         return 1;
     }
     return;
@@ -1152,7 +1431,7 @@ END
     $r->print(<<"END");
 <br />
 <br />
-<input type="submit" name="sub" value="Store Changes" />
+<input type="submit" name="sub" value="Save Changes" />
 <br />
 <br />
 Note: $lt{'thde'}
@@ -1337,7 +1616,7 @@ sub handler {
                       }));
 
     push (@Options,({ action   => 'changemsgforward',
-                      linktext => 'Change Message Forwarding and Notification Addresses',
+                      linktext => 'Change Message Forwarding and Notification Email Addresses',
                       href     => '/adm/preferences',
                       help     => 'Prefs_Forwarding',
                       breadcrumb => 
@@ -1349,7 +1628,7 @@ sub handler {
                       breadcrumb => 
                           { href => '/adm/preferences?action=changemsgforward',
                             text => 'Change Message Forwarding'},
-                      printmenu => 'yes',
+                      printmenu => 'no',
                       subroutine => \&verify_and_change_msgforward }));
     my $aboutmeaction=
         '/adm/'.$env{'user.domain'}.'/'.$env{'user.name'}.'/aboutme';
@@ -1421,20 +1700,21 @@ sub handler {
                       printmenu => 'yes',
                       subroutine => \&verify_and_change_discussion, }
                     ));
-                       
+
+    my $role = ($env{'user.adv'} ? 'Roles' : 'Course');
     push (@Options,({ action   => 'changerolespref',
-                      linktext => 'Change Roles Page Preferences',
+                      linktext => 'Change '.$role.' Page Preferences',
                       href     => '/adm/preferences',
                       subroutine => \&rolesprefchanger,
                       breadcrumb =>
                           { href => '/adm/preferences?action=changerolespref',
-                            text => 'Change Roles Pref'},
+                            text => 'Change '.$role.' Page Pref'},
                       },
                     { action   => 'verify_and_change_rolespref',
                       subroutine => \&verify_and_change_rolespref,
                       breadcrumb =>
                           { href => '/adm/preferences?action=changerolespref',
-                            text => 'Change Roles Preferences'},
+                            text => 'Change '.$role.' Page Preferences'},
                       printmenu => 'yes',
                       }));
 
@@ -1466,6 +1746,22 @@ sub handler {
 		      }));
     }
 
+    push (@Options,({ action   => 'changeicons',
+                      linktext => 'Change How Menus are Displayed',
+                      href     => '/adm/preferences',
+                      subroutine => \&iconchanger,
+                      breadcrumb =>
+                          { href => '/adm/preferences?action=changeicons',
+                            text => 'Change Main Menu'},
+                      },
+                    { action   => 'verify_and_change_icons',
+                      subroutine => \&verify_and_change_icons,
+                      breadcrumb =>
+                          { href => '/adm/preferences?action=changeicons',
+                            text => 'Change Main Menu'},
+                      printmenu => 'yes',
+                      }));
+
     if (&Apache::lonnet::allowed('whn',$env{'request.course.id'})
 	|| &Apache::lonnet::allowed('whn',$env{'request.course.id'}.'/'
 				    .$env{'request.course.sec'})) {
