@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # portfolio browser
 #
-# $Id: portfolio.pm,v 1.179 2007/05/02 01:33:50 albertel Exp $
+# $Id: portfolio.pm,v 1.184 2007/06/11 21:29:44 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -567,7 +567,7 @@ sub delete_confirmed {
 					       $delete_file);
         if ($result ne 'ok') {
 	    $r->print('<span class="LC_error">'.
-                     &mt('An error occured ([_1]) while trying to delete 
+                     &mt('An error occurred ([_1]) while trying to delete 
                          [_2].',$result,&display_file(undef, $delete_file)).
                       '</span><br /><br />');
         } else {
@@ -588,7 +588,7 @@ sub delete_confirmed {
                     &Apache::lonnet::modify_access_controls($file_name,\%changes,
                                                             $udom,$uname);
                     if ($outcome ne 'ok') {
-                           $r->print('<br />'.&mt("An error occured ([_1]) while ".
+                           $r->print('<br />'.&mt("An error occurred ([_1]) while ".
                                "trying to delete access controls for the file.",$outcome).
                                '</span><br /><br />');
                     } else {
@@ -596,7 +596,7 @@ sub delete_confirmed {
                             $r->print('<br />'.&mt('Access controls also deleted for the file.').'<br /><br />');
                         } else {
                             $r->print('<span class="LC_error">'.'<br />'.
-                               &mt("An error occured ([_1]) while ".
+                               &mt("An error occurred ([_1]) while ".
                                    "trying to delete access controls for the file.",$deloutcome).
                                    '</span><br /><br />');
                         }
@@ -626,7 +626,7 @@ sub delete_dir_confirmed {
 					       $directory_name);
 					       
     if ($result ne 'ok') {
-	$r->print('<span class="LC_error"> An error occured (dir) ('.$result.
+	$r->print('<span class="LC_error"> An error occurred (dir) ('.$result.
 		  ') while trying to delete '.$directory_name.'</span><br />');
     } else {
         # now remove from recent
@@ -681,7 +681,7 @@ sub rename_confirmed {
         $chg_access = &access_for_renamed($filenewname,$group,$udom,$uname);
     } else {      
 	$r->print('<span class="LC_error">'.
-		  &mt('An error occured ([_1]) while trying to rename [_2]'
+		  &mt('An error occurred ([_1]) while trying to rename [_2]'
 		      .' to [_3]',$result,&display_file(),
 		      &display_file('',$filenewname)).'</span><br />');
         return;
@@ -718,13 +718,13 @@ sub access_for_renamed {
             &Apache::lonnet::modify_access_controls($oldfile,\%change_old,
 						    $udom,$uname);
         if ($outcome ne 'ok') {
-            $chg_text ='<br /><br />'.&mt("An error occured ([_1]) while ".
+            $chg_text ='<br /><br />'.&mt("An error occurred ([_1]) while ".
                 "trying to delete access control records for the old name.",$outcome).
                 '</span><br />';
         } else {
             if ($deloutcome ne 'ok') {
                 $chg_text = '<br /><br /><span class="LC_error"><br />'.
-		    &mt("An error occured ([_1]) while ".
+		    &mt("An error occurred ([_1]) while ".
 			"trying to delete access control records for the old name.",$deloutcome).
 			'</span><br />';
             }
@@ -734,7 +734,7 @@ sub access_for_renamed {
                                                     $udom,$uname);
         if ($outcome ne 'ok') {
             $chg_text .= '<br /><br />'.
-		&mt("An error occured ([_1]) while ".
+		&mt("An error occurred ([_1]) while ".
                 "trying to update access control records for the new name.",$outcome).
                 '</span><br />';
         }
@@ -1818,7 +1818,7 @@ sub upload {
 					$port_path.$env{'form.currentpath'},
 					$mode,\%allfiles,\%codebase);
     if ($result !~ m|^/uploaded/|) {
-	$r->print('<span class="LC_error">'.'An errror occured ('.$result.
+	$r->print('<span class="LC_error">'.'An error occurred ('.$result.
 		  ') while trying to upload '.&display_file().'</span><br />');
 	$r->print(&done('Back',$url));
     } else {
@@ -1829,8 +1829,12 @@ sub upload {
     <input type="hidden" name="fieldname"   value="$env{'form.fieldname'}" />
     <input type="hidden" name="mode"        value="$env{'form.mode'}" />
 STATE
-	    $r->print("<p>Completed upload of the file. This file contained references to other files. You can upload these now: </p>");
-	    $r->print(&Apache::londocs::ask_for_embedded_content('/adm/portfolio',$state,\%allfiles,\%codebase,{'error_on_invalid_names' => 1}));
+            $r->print("<h2>".&mt("Reference Warning")."</h2>");
+            $r->print("<p>".&mt("Completed upload of the file. This file contained references to other files. You must upload the referenced files or else the uploaded file may not work properly.")."</p>");
+            $r->print("<p>".&mt("Please select the locations from which the referenced files are to be uploaded.")."</p>");
+	    $r->print(&Apache::londocs::ask_for_embedded_content('/adm/portfolio',$state,\%allfiles,\%codebase,
+				      {'error_on_invalid_names'   => 1,
+				       'ignore_remote_references' => 1,}));
 	    $r->print('<p>Or '.&done('Return to directory listing',$url).'</p>');
 	} else {
 	    $r->print(&done(undef,$url));
@@ -1842,11 +1846,16 @@ sub upload_embedded {
     my ($r,$url,$group)=@_;
     for (my $i=0; $i<$env{'form.number_embedded_items'}; $i++) {
 	next if (!exists($env{'form.embedded_item_'.$i.'.filename'}));
-	
+	my $orig_uploaded_filename = 
+	    $env{'form.embedded_item_'.$i.'.filename'};
+
 	$env{'form.embedded_orig_'.$i} = 
 	    &unescape($env{'form.embedded_orig_'.$i});
 	my ($path,$fname) = 
 	    ($env{'form.embedded_orig_'.$i} =~ m{(.*/)([^/]*)});
+	# no path, whole string is fname
+	if (!$fname) { $fname = $env{'form.embedded_orig_'.$i} };
+
 	$path = $env{'form.currentpath'}.$path;
 	$fname = &Apache::lonnet::clean_filename($fname);
 
@@ -1868,8 +1877,8 @@ sub upload_embedded {
 	    &Apache::lonnet::userfileupload('embedded_item_'.$i,'',
 					    $port_path.$path);
 	if ($result !~ m|^/uploaded/|) {
-	    $r->print('<span class="LC_error">'.'An errror occured ('.$result.
-		      ') while trying to upload '.&display_file($path,$fname).'</span><br />');
+	    $r->print('<span class="LC_error">'.'An error occurred ('.$result.
+		      ') while trying to upload '.$orig_uploaded_filename.' for embedded element '.$env{'form.embedded_orig_'.$i}.'</span><br />');
 	    next;
 	} else {
 	    $r->print("<p> Uploaded ".
@@ -1951,7 +1960,7 @@ sub createdir {
         my $result=&Apache::lonnet::mkdiruserfile($uname,$udom,
 	         $port_path.$env{'form.currentpath'}.$newdir);
         if ($result ne 'ok') {
-    	    $r->print('<span class="LC_error">'.'An errror occured ('.$result.
+    	    $r->print('<span class="LC_error">'.'An error occurred ('.$result.
 	    	      ') while trying to create a new directory '.&display_file().'</span><br />');
         }
     }
