@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.115 2007/02/21 20:34:58 albertel Exp $
+# $Id: lonplot.pm,v 1.117 2007/05/23 22:36:28 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -217,11 +217,11 @@ my %gnuplot_defaults =
 	 choices     => ['100','200','500','1000','2000','5000']
 	 },
      align        => {
-	 default     => 'center',
-	 test        => sub {$_[0]=~/^(left|right|center)$/},
+	 default     => 'middle',
+	 test        => sub {$_[0]=~/^(left|right|middle|center)$/},
 	 description => 'alignment for image in html',
 	 edit_type   => 'choice',
-	 choices     => ['left','right','center']
+	 choices     => ['left','right','middle']
 	 },
      texwidth     => {
          default     => '93',
@@ -550,7 +550,9 @@ sub start_gnuplot {
     } elsif ($target eq 'edit') {
 	$result .= &Apache::edit::tag_start($target,$token,'GnuPlot');
 	$result .= &edit_attributes($target,$token,\%gnuplot_defaults,
-				    \@gnuplot_edit_order);
+				    \@gnuplot_edit_order)
+	    .&Apache::edit::end_row()
+	    .&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
 	my $constructtag=&Apache::edit::get_new_args
 	    ($token,$parstack,$safeeval,keys(%gnuplot_defaults));
@@ -717,9 +719,7 @@ sub start_title {
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token,'Plot Title');
 	my $text=&Apache::lonxml::get_all_text("/title",$parser,$style);
-	$result.=&Apache::edit::end_row().
-	    &Apache::edit::start_spanning_row().
-	    &Apache::edit::editline('',$text,'',60);
+	$result.=&Apache::edit::editline('',$text,'',60);
     } elsif ($target eq 'modified') {
 	$result.=&Apache::edit::rebuild_tag($token);
 	$result.=&Apache::edit::modifiedfield("/title",$parser);
@@ -750,9 +750,7 @@ sub start_xlabel {
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token,'Plot Xlabel');
 	my $text=&Apache::lonxml::get_all_text("/xlabel",$parser,$style);
-	$result.=&Apache::edit::end_row().
-	    &Apache::edit::start_spanning_row().
-	    &Apache::edit::editline('',$text,'',60);
+	$result.=&Apache::edit::editline('',$text,'',60);
     } elsif ($target eq 'modified') {
 	$result.=&Apache::edit::rebuild_tag($token);	
 	$result.=&Apache::edit::modifiedfield("/xlabel",$parser);
@@ -784,9 +782,7 @@ sub start_ylabel {
     } elsif ($target eq 'edit') {
 	$result .= &Apache::edit::tag_start($target,$token,'Plot Ylabel');
 	my $text = &Apache::lonxml::get_all_text("/ylabel",$parser,$style);
-	$result .= &Apache::edit::end_row().
-	    &Apache::edit::start_spanning_row().
-	    &Apache::edit::editline('',$text,'',60);
+	$result .= &Apache::edit::editline('',$text,'',60);
     } elsif ($target eq 'modified') {
 	$result.=&Apache::edit::rebuild_tag($token);
 	$result.=&Apache::edit::modifiedfield("/ylabel",$parser);
@@ -858,13 +854,15 @@ sub start_curve {
     } elsif ($target eq 'edit') {
 	$result .= &Apache::edit::tag_start($target,$token,'Curve');
 	$result .= &edit_attributes($target,$token,\%curve_defaults,
-                                    \@curve_edit_order);
+                                    \@curve_edit_order)
+	    .&Apache::edit::end_row()
+	    .&Apache::edit::start_spanning_row();
+
     } elsif ($target eq 'modified') {
 	my $constructtag=&Apache::edit::get_new_args
 	    ($token,$parstack,$safeeval,keys(%curve_defaults));
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.= &Apache::edit::handle_insert();
 	}
     }
     return $result;
@@ -902,9 +900,7 @@ sub start_function {
     } elsif ($target eq 'edit') {
 	$result .= &Apache::edit::tag_start($target,$token,'Gnuplot compatible curve function');
 	my $text = &Apache::lonxml::get_all_text("/function",$parser,$style);
-	$result .= &Apache::edit::end_row().
-	    &Apache::edit::start_spanning_row().
-	    &Apache::edit::editline('',$text,'',60);
+	$result .= &Apache::edit::editline('',$text,'',60);
     } elsif ($target eq 'modified') {
 	$result.=&Apache::edit::rebuild_tag($token);
 	$result.=&Apache::edit::modifiedfield("/function",$parser);
@@ -979,9 +975,7 @@ sub start_data {
     } elsif ($target eq 'edit') {
 	$result .= &Apache::edit::tag_start($target,$token,'Comma or space deliminated curve data');
 	my $text = &Apache::lonxml::get_all_text("/data",$parser,$style);
-	$result .= &Apache::edit::end_row().
-	    &Apache::edit::start_spanning_row().
-	    &Apache::edit::editline('',$text,'',60);
+	$result .= &Apache::edit::editline('',$text,'',60);
     } elsif ($target eq 'modified') {
 	$result.=&Apache::edit::rebuild_tag($token);
 	$result.=&Apache::edit::modifiedfield("/data",$parser);
