@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.81 2006/11/09 21:31:54 albertel Exp $
+# $Id: lontexconvert.pm,v 1.82 2007/06/13 00:21:03 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -151,7 +151,7 @@ ENDCONV
 
 sub clean_out_math_mode {
     my ($texstring)=@_;
-    $$texstring=~s/(?!\\)\$//g;
+    $$texstring=~s/(?<!\\)\$//g;
     $$texstring=~s/\\[\)\(\]\[]//g;
     $$texstring=~s/\\ensuremath//g;
     return '';
