@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.76 2006/12/12 18:49:27 albertel Exp $
+# $Id: lonpage.pm,v 1.79 2007/05/23 17:04:57 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -270,7 +270,7 @@ sub handler {
 				  }
 			      }
                               my $output=Apache::lonnet::ssi($src,%posthash);
-			      $output=~s|//(\s*<!--)? BEGIN LON-CAPA Internal.+// END LON-CAPA Internal\s*(-->)?\s||gs;
+			      $output=~s|//(\s*<!--)? BEGIN LON-CAPA Internal.+?// END LON-CAPA Internal\s*(-->)?\s||gs;
                               if ($target eq 'tex') {
 				  $output =~ s/^([^&]+)\\begin{document}//;
 				  $output =~ s/\\end{document}//;
@@ -411,6 +411,10 @@ sub handler {
 		      } else {
 			  $r->print('<table width="100%" cols="'.$lcm.'" border="0">');
 		      }
+# which icons do we use?
+                      my $extension='png';
+                      if ($env{'environment.icons'} eq 'classic') { $extension='gif'; }
+# generate rows
                       for ($i=0;$i<=$#rows;$i++) {
 			if ($rows[$i]) {
 			    unless ($target eq 'tex') {
@@ -431,14 +435,14 @@ sub handler {
                               unless ($hash{'src_'.$rid} =~ m-^/uploaded/-) { 
                                   $metainfo ='<a name="'.&escape($symb).'" />'.
                                   '<a href="'.$metalink{$rid}.'" target="LONcatInfo">'.
-                                  '<img src="/adm/lonMisc/cat_button.gif" border=0>'.
-                                  '</img></a>';
+                                  '<img src="/adm/lonMisc/cat_button.'.$extension.'" class="LC_icon" />'.
+                                  '</a>';
                               }
                               $metainfo .= '<a href="/adm/evaluate?postdata='.
 				  &escape($esrc).
                                   '" target="LONcatInfo">'.
-                                  '<img src="/adm/lonMisc/eval_button.gif" border=0>'.
-                                  '</img></a>';
+                                  '<img src="/adm/lonMisc/eval_button.'.$extension.'" class="LC_icon" />'.
+                                  '</a>';
                               if (
  ($hash{'src_'.$rid}=~/\.(problem|exam|quiz|assess|survey|form)$/) &&
  (&Apache::lonnet::allowed('mgr',$env{'request.course.id'})) && 
@@ -452,18 +456,18 @@ sub handler {
                   '<a href="/adm/grades?symb='.&escape($symb).
 #                 '&command=submission" target="LONcatInfo">'.
                   '&command=submission">'.
-                          '<img src="/adm/lonMisc/subm_button.gif" border=0>'.
-			  '</img></a>'.
+                          '<img src="/adm/lonMisc/subm_button.'.$extension.'" class="LC_icon" />'.
+			  '</a>'.
                   '<a href="/adm/grades?symb='.&escape($symb).
 #                  '&command=gradingmenu" target="LONcatInfo">'.
                   '&command=gradingmenu">'.
-                          '<img src="/adm/lonMisc/pgrd_button.gif" border=0>'.
-			  '</img></a>'.
+                          '<img src="/adm/lonMisc/pgrd_button.'.$extension.'" class="LC_icon" />'.
+			  '</a>'.
                   '<a href="/adm/parmset?symb='.&escape($symb).
 #                          '" target="LONcatInfo">'.
                           '" >'.
-                          '<img src="/adm/lonMisc/pprm_button.gif" border=0>'.
-			      '</img></a>';
+                          '<img src="/adm/lonMisc/pprm_button.'.$extension.'" class="LC_icon" />'.
+			      '</a>';
                               }
                               $metainfo.='<br></br>';
 			    unless ($target eq 'tex') {
@@ -500,13 +504,11 @@ sub handler {
                                       '.pageseparators'} eq 'yes') {
                                       unless($target eq 'tex') {
                                           $r->print('<hr />');
-                                      } else {
-                                          $r->print('\hline');
-                                      }
+                                      } 
 				  }
 			      } elsif ($cellemb{$rid} eq 'img') {
                                   $r->print('>'.$metainfo.'<img src="'.
-                                    $hash{'src_'.$rid}.'"></img>');
+                                    $hash{'src_'.$rid}.'" />');
 			      } elsif ($cellemb{$rid} eq 'emb') {
                                   $r->print('>'.$metainfo.'<embed src="'.
                                     $hash{'src_'.$rid}.'"></embed>');
